@@ -31,8 +31,12 @@
 #include "mesomery-arrow.h"
 #include "mesomer.h"
 #include <glib/gi18n-lib.h>
-#include <cmath>
 #include <set>
+#include <cmath>
+#include <cstring>
+
+using namespace gcu;
+using namespace std;
 
 namespace gcp {
 
@@ -775,10 +779,12 @@ double Mesomery::GetYAlign ()
 	Object *pObj;
 	pObj = GetFirstChild (i);
 	double y = DBL_MAX, new_y;
-	while (pObj)
+	while (pObj) {
 		if (pObj->GetType () == MesomerType)
 			if ((new_y = pObj->GetYAlign ()) < y)
 				y = new_y;			
+		pObj = GetNextChild (i);
+	}
 	return y;
 }
 
