@@ -37,6 +37,10 @@
 #include <canvas/gprintable.h>
 #include <glib/gi18n-lib.h>
 #include <stdexcept>
+#include <cstring>
+
+using namespace gcu;
+using namespace std;
 
 namespace gcp {
 
@@ -599,6 +603,8 @@ bool Text::LoadNode (xmlNodePtr node, unsigned &pos, int level)
 void Text::Add (GtkWidget* w)
 {
 	WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (w), "data");
+	if (pData->Items[this] != NULL)
+		return;
 	Theme *pTheme = pData->m_View->GetDoc ()->GetTheme ();
 	if (m_ascent <= 0) {
 		PangoContext* pc = pData->m_View->GetPangoContext ();
