@@ -47,6 +47,7 @@
 #include <fstream>
 #include <map>
 #include <string>
+#include <cstring>
 
 /*
 Derivation of a new widget from gnome_canvas with an event for updating canvas size
@@ -146,6 +147,9 @@ void gnome_canvas_gcp_update_bounds (GnomeCanvasGCP *canvas)
 	pView->UpdateSize (x1, y1, x2, y2);
 }
 
+using namespace gcu;
+using namespace std;
+
 namespace gcp {
 
 bool on_event (GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
@@ -171,8 +175,6 @@ void on_receive (GtkClipboard *clipboard, GtkSelectionData *selection_data, View
 	pView->OnReceive (clipboard, selection_data);
 }
 
-using namespace std;
-
 View::View (Document *pDoc, bool Embedded)
 {
 	m_pDoc = pDoc;
@@ -815,9 +817,10 @@ bool View::OnKeyPress (GtkWidget* w, GdkEventKey* event)
 				break;
 			}
 			if (Z) {
-				Tools *tools = static_cast<Tools*> (pApp->GetDialog ("tools"));
-				tools->SetElement (Z);
-				if (atom && atom->GetZ () != Z && Element::GetElement (Z)->GetMaxBonds () >= min_bonds) {
+				if (!atom) {
+					Tools *tools = static_cast<Tools*> (pApp->GetDialog ("tools"));
+					tools->SetElement (Z);
+				} else if (atom->GetZ () != Z && Element::GetElement (Z)->GetMaxBonds () >= min_bonds) {
 					Object *group = atom->GetGroup ();
 					Operation *op = m_pDoc->GetNewOperation (GCP_MODIFY_OPERATION);
 					op->AddObject (group);
