@@ -30,6 +30,9 @@
 #include "application.h"
 #include "operation.h"
 #include "theme.h"
+#include <cstring>
+
+using namespace gcu;
 
 namespace gcp {
 
