@@ -34,8 +34,12 @@
 #include <sys/stat.h>
 #include <cmath>
 #include <cstdlib>
+#include <cstring>
 
-using namespace gcu;
+using namespace std;
+
+namespace gcu
+{
 
 Application::Application (string name, string datadir, char const *help_name, char const *icon_name)
 {
@@ -111,8 +115,6 @@ Application::Application (string name, string datadir, char const *help_name, ch
 
 Application::~Application ()
 {
-	if (CurDir)
-		g_free (CurDir);
 	g_object_unref (m_RecentManager);
 }
 
@@ -142,9 +144,12 @@ bool Application::HasHelp ()
 
 void Application::SetCurDir (char const* dir)
 {
-	if (CurDir)
-		g_free (CurDir);
-	CurDir = g_strdup (dir);
+	CurDir = dir;
+}
+
+void Application::SetCurDir (string const &dir)
+{
+	CurDir = dir;
 }
 
 void Application::OnMail (char const *MailAddress)
@@ -242,3 +247,5 @@ void Application::RemoveDocument (Document *Doc)
 	if (m_Docs.size () == 0 && gtk_main_level ())
 		NoMoreDocsEvent ();
 }
+
+}	//	namespace gcu
