@@ -23,6 +23,7 @@
  */
 
 #include "config.h"
+#include <cstring>
 #include "crystaldoc.h"
 #include "crystalview.h"
 #include "cylinder.h"
@@ -34,19 +35,24 @@
 #include <libintl.h>
 #include <clocale>
 #include <cmath>
-#include <cstring>
 #include <vector>
 #ifdef HAVE_OPENBABEL_2_2
 #	include <list>
-using namespace OpenBabel;
+#else
+#	include <openbabel/math/vector3.h>
 #endif
 #include <GL/gl.h>
+#include <cstring>
 
 #define __max(x,y)  ((x) > (y)) ? (x) : (y)
 #define __min(x,y)  ((x) < (y)) ? (x) : (y)
 #define PREC 1e-3
 
-namespace gcu {
+using namespace OpenBabel;
+using namespace std;
+
+namespace gcu
+{
 	
 gchar const *LatticeName[] = {
 	"simple cubic",
@@ -65,10 +71,6 @@ gchar const *LatticeName[] = {
 	"triclinic"
 };
 
-}
-
-using namespace gcu;
-
 #ifdef HAVE_OPENBABEL_2_2
 CrystalDoc::CrystalDoc (Application *App): GLDocument (App),
 	m_SpaceGroup (NULL)
@@ -650,6 +652,7 @@ xmlDocPtr CrystalDoc::BuildXMLTree()
 	gchar buf[256];
 	xmlDocPtr xml;
 	xmlNodePtr node;
+	xmlNsPtr ns;
 	char *old_num_locale;
 
 	xml = xmlNewDoc((xmlChar*)"1.0");
@@ -658,7 +661,9 @@ xmlDocPtr CrystalDoc::BuildXMLTree()
 	old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
 	setlocale(LC_NUMERIC, "C");
 	xmlDocSetRootElement (xml,  xmlNewDocNode(xml, NULL, (xmlChar*)"crystal", NULL));
-	
+	ns = xmlNewNs (xml->children, (xmlChar*) "http://www.nongnu.org/gcrystal", (xmlChar*) "gcry");
+	xmlSetNs (xml->children, ns);
+
 	try
 	{
 		node = xmlNewDocNode(xml, NULL, (xmlChar*)"generator", (xmlChar*)GetProgramId());
@@ -866,3 +871,5 @@ bool CrystalDoc::ImportOB (OBMol &mol)
 	return true;
 }
 #endif
+
+}	//	namespace gcu
