@@ -25,9 +25,11 @@
 #include "matrix.h"
 #include <cmath>
 
-using namespace gcu;
 using namespace OpenBabel;
 
+namespace gcu
+{
+
 Matrix::Matrix()
 {
 }
@@ -175,3 +177,5 @@ GLMatrix::GLMatrix ()
 GLMatrix::~GLMatrix ()
 {
 }
+
+}	//	namespace gcu
