@@ -24,6 +24,9 @@
 #include <gcu/gtkchem3dviewer.h>
 #include <gcu/gtkcrystalviewer.h>
 #include <gcu/chem3ddoc.h>
+#include <gcp/application.h>
+#include <gcp/document.h>
+#include <gcp/view.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkplug.h>
@@ -33,12 +36,32 @@
 #include <sstream>
 #include <string>
 #include <map>
+#include <string>
+#include <cstring>
 
 using namespace std;
 using namespace gcu;
 
 static bool loaded_radii = false;
 
+class MozPaintApp: public gcp::Application
+{
+public:
+	MozPaintApp ();
+	virtual ~MozPaintApp ();
+
+	void OnFileNew (char const *Theme = NULL) {}
+	GtkWindow* GetWindow() {return NULL;}
+};
+
+MozPaintApp::MozPaintApp (): gcp::Application ()
+{
+}
+
+MozPaintApp::~MozPaintApp ()
+{
+}
+
 class ChemComp
 {
 public:
@@ -55,7 +78,9 @@ private:
 	string Filename, MimeType;
 	GtkWidget *Plug, *Viewer;
 	GdkWindow *Parent;
+	gcp::Document *Doc;
 	map<string, string> Params;
+	MozPaintApp *gcpApp;
 };
 
 ChemComp::ChemComp (void* instance, string& mime_type)
@@ -64,6 +89,8 @@ ChemComp::ChemComp (void* instance, string& mime_type)
 	MimeType = mime_type;
 	Xid = 0;
 	Plug = NULL;
+	Doc = NULL;
+	gcpApp = NULL;
 }
 
 ChemComp::~ChemComp ()
@@ -95,7 +122,12 @@ void ChemComp::SetWindow (XID xid)
 			GDK_WINDOW_XID (Plug->window));
 		if (MimeType == "application/x-gcrystal")
 			Viewer = gtk_crystal_viewer_new (NULL);
-		else
+		else if (MimeType == "application/x-gchempaint") {
+			if (!gcpApp)
+				gcpApp = new MozPaintApp ();
+			Doc = new gcp::Document (gcpApp, true, NULL);
+			Viewer = Doc->GetView ()->CreateNewWidget ();
+		} else
 			Viewer = gtk_chem3d_viewer_new (NULL);
 		gtk_container_add (GTK_CONTAINER (Plug), Viewer);
 		gtk_widget_show_all (Plug);
@@ -114,6 +146,13 @@ void ChemComp::SetFilename (string& filename)
 		if (!xml || !xml->children || strcmp ((char*) xml->children->name, "crystal"))
 			return;
 		gtk_crystal_viewer_set_data (GTK_CRYSTAL_VIEWER (Viewer), xml->children);
+		xmlFree (xml);
+	} else 	if (MimeType == "application/x-gchempaint") {
+		xmlDocPtr xml = xmlParseFile (filename.c_str ());
+		if (!xml || !xml->children || strcmp ((char*) xml->children->name, "chemistry"))
+			return;
+		Doc->Load (xml->children);
+		xmlFree (xml);
 	} else {
 		gtk_chem3d_viewer_set_uri_with_mime_type (GTK_CHEM3D_VIEWER (Viewer),
 				filename.c_str (), MimeType.c_str ());
