@@ -34,6 +34,9 @@
 #include <glib/gi18n-lib.h>
 #include <cmath>
 
+using namespace gcu;
+using namespace std;
+
 gcpBondTool::gcpBondTool (gcp::Application *App, string ToolId, unsigned nPoints): gcp::Tool (App, ToolId)
 {
 	points = (nPoints)? gnome_canvas_points_new (nPoints): NULL;
@@ -195,7 +198,7 @@ void gcpBondTool::OnDrag ()
 		Object* pObject = NULL;
 		if (pItem) {
 			pObject = (Object*) g_object_get_data (G_OBJECT (pItem), "object");
-			if (pObject == m_pObject || ((pObject->GetType () == FragmentType) && dynamic_cast<gcp::Fragment*> (pObject)->GetAtom () == m_pObject)) {
+			if (pObject && (pObject == m_pObject || ((pObject->GetType () == FragmentType) && dynamic_cast<gcp::Fragment*> (pObject)->GetAtom () == m_pObject))) {
 				if (!m_AutoDir)
 					return;
 			} else
