@@ -55,7 +55,9 @@
 #	include <openbabel/format.h>
 #	include <openbabel/obconversion.h>
 #	include <openbabel/math/matrix3x3.h>
+using namespace OpenBabel;
 #endif
+#include <cstring>
 
 #define SAVE	1
 #define LOAD	2
